##########
User guide
##########


.. toctree::
    :maxdepth: 2

    install
    example
    workflow
    definitions
    detailed_examples
    joint_models_estimating_parameters
    constructing_contours
    description_cheat_sheet

.. note::
    This user guide describes the newest version of virocon. Version 2.0 of virocon was a major
    update such that code from versions 1.X does not work with virocon 2.X. The old user guide for
    version 1 can be downloaded here_.

.. _here: https://github.com/virocon-organization/virocon/blob/main/docs/User_Guide_VC1.pdf
